==> App-bif-0.1.5_4.tar.gz: App-bif-0.1.5_4/lib/App/bif/update.pm <==
package App::bif::update;
use strict;
use warnings;
use Bif::Mo;

our $VERSION = '0.1.5_4';
extends 'App::bif';

sub run {
    my $self = shift;
    my $opts = $self->opts;
    my $info = $self->get_topic( $self->uuid2id( $opts->{id} ) );

    return $self->new_cmd(
        "App::bif::update::$info->{kind}",
        opts => {
            id      => $info->{id},
            title   => $opts->{title},
            message => $opts->{message}
        }
    )->run;
}

1;
__END__

=head1 NAME

=for bif-doc #modify

bif-update - change or comment a topic

=head1 VERSION

0.1.5_4 (2015-08-04)

=head1 SYNOPSIS

    bif update ID [STATUS] [OPTIONS...]

=head1 DESCRIPTION

Add a comment to a topic, possibly setting a new status at the same
time. Valid values for a topics's status depend on the projects it is
associated with. The list of valid status for a project can be found
using L<bif-list-status>(1).

=head1 ARGUMENTS

=over

=item ID

A topic ID, a topic ID.UPDATE_ID, or project PATH. Required.

=item STATUS

The new status for the topic. The status cannot be set when commenting
as a reply to another change.

=back

=head1 OPTIONS

=over

=item --title, -t

The new title for the topic.  The title cannot be set when commenting
as a reply to another change.

=item --message, -m

The message describing this issue in detail. If this option is not used
an editor will be invoked.

=back

=head1 SEE ALSO

L<bif>(1)

=head1 AUTHOR

Mark Lawrence E<lt>nomad@null.netE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2013-2015 Mark Lawrence <nomad@null.net>

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.

==> App-bif-0.1.5_5.tar.gz: App-bif-0.1.5_5/lib/App/bif/update.pm <==
package App::bif::update;
use strict;
use warnings;
use Bif::Mo;

our $VERSION = '0.1.5_5';
extends 'App::bif';

sub run {
    my $self = shift;
    my $opts = $self->opts;
    my $info = $self->get_node( $self->uuid2id( $opts->{id} ) );

    return $self->new_cmd(
        "App::bif::update::$info->{kind}",
        opts => {
            id      => $info->{id},
            title   => $opts->{title},
            message => $opts->{message}
        }
    )->run;
}

1;
__END__

=head1 NAME

=for bif-doc #modify

bif-update - change or comment a node

=head1 VERSION

0.1.5_5 (2015-08-13)

=head1 SYNOPSIS

    bif update ID [STATUS] [OPTIONS...]

=head1 DESCRIPTION

Add a comment to a node, possibly setting a new status at the same
time. Valid values for a nodes's status depend on the projects it is
associated with. The list of valid status for a project can be found
using L<bif-list-status>(1).

=head1 ARGUMENTS

=over

=item ID

A node ID, a node ID.UPDATE_ID, or project PATH. Required.

=item STATUS

The new status for the node. The status cannot be set when commenting
as a reply to another change.

=back

=head1 OPTIONS

=over

=item --title, -t

The new title for the node.  The title cannot be set when commenting as
a reply to another change.

=item --message, -m

The message describing this issue in detail. If this option is not used
an editor will be invoked.

=back

=head1 SEE ALSO

L<bif>(1)

=head1 AUTHOR

Mark Lawrence E<lt>nomad@null.netE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2013-2015 Mark Lawrence <nomad@null.net>

This program is free software; you can redistribute it and/or modify it
under the terms of the GNU General Public License as published by the
Free Software Foundation; either version 3 of the License, or (at your
option) any later version.
